==> tctl-0.0.2.tar.gz: tctl-0.0.2/tctl/terminal.py <==

from . import version

prompt = """-----------------------------------------------------
 _______            _       _             _
|__   __|          | |     | |           (_)
   | |_ __ __ _  __| | ___ | | ___   __ _ _  ___ ___
   | | '__/ _` |/ _` |/ _ \| |/ _ \ / _` | |/ __/ __|
   | | | | (_| | (_| | (_) | | (_) | (_| | | (__\__ \\
   |_|_|  \__,_|\__,_|\___/|_|\___/ \__, |_|\___|___/
                                     __/ |
   T R A D I N G   C L O U D        |___/

-----------------------------------------------------
        tctl {version} - Tradologics Controller
-----------------------------------------------------

For more information on Tradologics and tctl,
please visit the following links:

Getting started:
https://docs.tradologics.com/

API reference:
https://docs.tradologics.com/api

How to use tctl:
https://docs.tradologics.com/tctl

-----------------------------------------------------
""".format(version=version.version)


logo = """
                                         @@@%
                                     @@@@@@@@@@@@
                                 @@@@@@@@@@@@@@@@@@@@@
                             , @@@@@@@@@@@@@@@@@@@@@@@@%
                         @@@@@@@@@ (@@@@@@@@@@@@@@@    %
                     @@@@@@@@@@@@@@@@@# @@@@@@@        %
                 @@@@@@@@@@@@@@@@@@@@@@@@@%@           %
             &@@@@# &@@@@@@@@@@@@@@@@@@   %@           %
         @@@@@@@@@@@@@@  @@@@@@@@@@       %@           %
     %@@@@@@@@@@@@@@@@@@@@@& %@           %@         &/
   @@@@@@@@@@@@@@@@@@@@@@@@,#             %@     @*
   @@@@@@@@@@@@@@@@@@@@     #             %@ @#
   @@@@@@@@@@@@@@@@         #            @#
   @@@@@@@@@@@@@@           #        @, @ %
   @@@@@@@@@@@@@@           #    @, @     %
   @@@@@@@@@@@@@@           # / @*        %
     #@@@@@@@@@@@        (& %@            %
         *@@@@@@@    && @@@@@@            %
              @@@@@ @@@@@@@@@@            %
                   @@@@@@@@@@@          @,
                  @@  @@@@@@@@      @. @  %
                  @@@@@@  @@@@  @  @      %
                  @@@@@@@@@@/  @          %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@            %
                  . @@@@@@@@@@        @ @(%
                  @@@@. &@@@@@    @ #&    %
                  @@@@@@@@@ #@@ &&        %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@          &
                      @@@@@@@@     *@
                          .@@@ #@
"""

==> tctl-0.0.9.tar.gz: tctl-0.0.9/tctl/terminal.py <==

from . import version

prompt = """-----------------------------------------------------
 _______            _       _             _
|__   __|          | |     | |           (_)
   | |_ __ __ _  __| | ___ | | ___   __ _ _  ___ ___
   | | '__/ _` |/ _` |/ _ \| |/ _ \ / _` | |/ __/ __|
   | | | | (_| | (_| | (_) | | (_) | (_| | | (__\__ \\
   |_|_|  \__,_|\__,_|\___/|_|\___/ \__, |_|\___|___/
                                     __/ |
   T R A D I N G   C L O U D        |___/

-----------------------------------------------------
        tctl {version} - Tradologics Controller
-----------------------------------------------------

For more information on Tradologics and tctl,
please visit the following links:

Getting started:
https://docs.tradologics.com/

API reference:
https://tradologics.com/docs/api

How to use tctl:
https://tradologics.com/tctl

-----------------------------------------------------
""".format(version=version.version)


logo = """
                                         @@@%
                                     @@@@@@@@@@@@
                                 @@@@@@@@@@@@@@@@@@@@@
                             , @@@@@@@@@@@@@@@@@@@@@@@@%
                         @@@@@@@@@ (@@@@@@@@@@@@@@@    %
                     @@@@@@@@@@@@@@@@@# @@@@@@@        %
                 @@@@@@@@@@@@@@@@@@@@@@@@@%@           %
             &@@@@# &@@@@@@@@@@@@@@@@@@   %@           %
         @@@@@@@@@@@@@@  @@@@@@@@@@       %@           %
     %@@@@@@@@@@@@@@@@@@@@@& %@           %@         &/
   @@@@@@@@@@@@@@@@@@@@@@@@,#             %@     @*
   @@@@@@@@@@@@@@@@@@@@     #             %@ @#
   @@@@@@@@@@@@@@@@         #            @#
   @@@@@@@@@@@@@@           #        @, @ %
   @@@@@@@@@@@@@@           #    @, @     %
   @@@@@@@@@@@@@@           # / @*        %
     #@@@@@@@@@@@        (& %@            %
         *@@@@@@@    && @@@@@@            %
              @@@@@ @@@@@@@@@@            %
                   @@@@@@@@@@@          @,
                  @@  @@@@@@@@      @. @  %
                  @@@@@@  @@@@  @  @      %
                  @@@@@@@@@@/  @          %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@            %
                  . @@@@@@@@@@        @ @(%
                  @@@@. &@@@@@    @ #&    %
                  @@@@@@@@@ #@@ &&        %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@            %
                  @@@@@@@@@@@@          &
                      @@@@@@@@     *@
                          .@@@ #@
"""
